"""
Application class that implements pyFoamRunner
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.Execution.AnalyzedRunner import AnalyzedRunner
from PyFoam.LogAnalysis.BoundingLogAnalyzer import BoundingLogAnalyzer
from PyFoam.RunDictionary.SolutionDirectory import SolutionDirectory

from PyFoam.Execution.ParallelExecution import LAMMachine

class Runner(PyFoamApplication):
    def __init__(self):
        description="""
        Runs an OpenFoam solver.  Needs the usual 3 arguments (<solver>
        <directory> <case>) and passes them on (plus additional arguments).
        Output is sent to stdout and a logfile inside the case directory
        (PyFoamSolver.logfile) The Directory PyFoamSolver.analyzed contains
        this information: a) Residuals and other information of the linear
        solvers b Execution time c) continuity information d) bounding of
        variables
        """
        
        PyFoamApplication.__init__(self,description=description)
        
    def addOptions(self):
        self.parser.add_option("--procnr",type="int",dest="procnr",default=None,help="The number of processors the run should be started on")
        self.parser.add_option("--machinefile",dest="machinefile",default=None,help="The machinefile that specifies the parallel machine")
        self.parser.add_option("--clear-case",action="store_true",default=False,dest="clearCase",help="Clear all timesteps except for the first before running")
        
    def run(self):
        if self.opts.clearCase:
            print "Clearing out old timesteps ...."
            
            cName=self.parser.getArgs()[2]
            sol=SolutionDirectory(cName)
            sol.clearResults()

        lam=None
        if self.opts.procnr!=None or self.opts.machinefile!=None:
            lam=LAMMachine(machines=self.opts.machinefile,nr=self.opts.procnr)
            
        run=AnalyzedRunner(BoundingLogAnalyzer(),argv=self.parser.getArgs(),server=True,lam=lam)

        run.start()
