"""Transform a Python data-structure into a OpenFOAM-File-Representation"""

from PyFoam.Error import error

class FoamFileGenerator(object):
    """Class that generates a OpenFOAM-compatible representation of a
    data-structure"""

    def __init__(self,data,header=None):
        """@param data: data structure that will be turned into a
        Foam-compatible file
        @param header: header information that is to be prepended
        """
        
        self.data=data
        self.header=header
        
    def makeString(self):
        """turns the data into a string"""
        result=""
        if self.header:
            result+="FoamFile\n{\n"+self.strDict(self.header,indent=1)+"}\n\n"
        if type(self.data)==dict:
            result+=self.strDict(self.data)
        elif type(self.data)==list:
            result+=self.strList(self.data)
        else:
            error("List or Dict expected,",type(self.data),"found in",self.data)
            
        return result
    
    def strDict(self,dic,indent=0):
        s=""
        for k,v in dic.iteritems():
            if k.find("anonymValue")==0:
                k=""
                
            s+=(" "*indent)+k
            if type(v)==str:
                s+=" "+v+";\n"
            elif type(v)==dict:
                s+="\n"+(" "*indent)+"{\n"
                s+=self.strDict(v,indent+2)
                s+="\n"+(" "*indent)+"}\n"
            elif type(v)==list:
                s+="\n"
                s+=self.strList(v,indent+2)+";\n"
            elif type(v)==tuple:
                s+=" "+self.strTuple(v,indent+2)+";\n"
            else:
                s+=" "+str(v)+";\n"
                
        return s
    
    def strList(self,lst,indent=0):
        s=""

        theLen=len(lst)
        
        if len(lst)>2 and len(lst)%2==0:
            if type(lst[0])==str and type(lst[1])==dict:
                theLen=len(lst)/2

        isVector=False
        if len(lst)==3:
            isVector=True
            for l in lst:
                try:
                    val=float(l)
                except ValueError:
                    isVector=False
                    
        if isVector:
            s+="( %s %s %s )" % tuple(lst)
        else:
            s+=(" "*indent)+str(theLen)+"\n"
            s+=(" "*indent)+"(\n"
            for v in lst:
                if type(v)==str:
                    s+=(" "*(indent+2))+v+"\n"
                elif type(v)==dict:
                    s+="\n"+(" "*(indent+2))+"{\n"
                    s+=self.strDict(v,indent+4)
                    s+="\n"+(" "*(indent+2))+"}\n"
                elif type(v)==list:
                    s+="\n"
                    s+=self.strList(v,indent+2)
                elif type(v)==tuple:
                    s+=" "+self.strTuple(v,indent+2)+" "
                else:
                    s+=(" "*(indent+2))+str(v)+"\n"

            s+=(" "*indent)+")\n"
        
        return s

    def strTuple(self,lst,indent=0):
        s=""

        for v in lst:
            if type(v)==str:
                s+=v+" "
            elif type(v)==dict:
                s+="{\n"
                s+=self.strDict(v,indent+4)
                s+="\n"+(" "*(indent+2))+"} "
            elif type(v)==list:
                s+=" "
                s+=self.strList(v,indent+2)
            else:
                s+=(" "*(indent+2))+str(v)+" "
            
        return s
